@@ -442,7 +442,7 @@ QString DatabaseManager::changePassword (const QString & newPassword) {
 						qDebug () << "succesfull migrated ";
 						db.close ();
 
-						ret = restoreDB ("NEW");
+						ret = oldDB->restoreDB ("NEW");
 						if (ret) {
 							qDebug () << "succesfull changed ";
 
@@ -460,6 +460,8 @@ QString DatabaseManager::changePassword (const QString & newPassword) {
 			}
 			else
 				result = "NEWqtwallet.db.sqlite cannot be reset";
+
+			oldDB->deleteDB("NEW");
 		}
 		else
 			result = "NEWqtwallet.db.sqlite cannot be opened";
