@@ -91,7 +91,13 @@ private slots:
     void windowDestroyedEdit(QObject* obj = 0);
     void sort ();
     void changePassword ();
+
     void _newLikeTarget ();
+    void _duplicateTarget ();
+
+    void newLikeTarget (Target * );
+    void duplicateTarget (Target * );
+
 	void _editcTarget();
 	void _clickBack();
 	void _deletecTarget();
